@@ -50,8 +50,7 @@ class VantagePro2(object):
     '''Communicates with the station by sending commands, reads the binary
     data and parsing it into usable scalar values.
 
-    :param url: A `PyLink` connection URL.
-    :param timeout: Set a read timeout value.
+    :param link: A `PyLink` connection.
     '''
 
     # device reply commands
@@ -64,12 +63,22 @@ class VantagePro2(object):
     ESC = '\x1b'
     OK = '\n\rOK\n\r'
 
-    def __init__(self, url, timeout=10):
-        self.link = link_from_url(url)
-        self.link.settimeout(timeout)
+    def __init__(self, link):
+        self.link = link
         self.link.open()
         self._check_revision()
 
+    @classmethod
+    def from_url(cls, url, timeout=10):
+        ''' Get device from url.
+
+        :param url: A `PyLink` connection URL.
+        :param timeout: Set a read timeout value.
+        '''
+        link = link_from_url(url)
+        link.settimeout(timeout)
+        return cls(link)
+
     @retry(tries=3, delay=1)
     def wake_up(self):
         '''Wakeup the station console.'''
@@ -165,7 +174,8 @@ class VantagePro2(object):
         for item in generator:
             if item['Datetime'] not in dates:
                 archives.append(item)
-        return archives
+                dates.append(item['Datetime'])
+        return archives.sorted_by('Datetime')
 
     def _get_archives_generator(self, start_date=None, stop_date=None):
         '''Get archive records generator until `start_date` and `stop_date`.'''
@@ -224,10 +234,12 @@ class VantagePro2(object):
                     break
                 elif r_time <= stop_date:
                     if start_date < r_time:
+                        not_in_range = False
                         msg = "Record-%.4d - Datetime : %s" % (r_index, r_time)
                         LOGGER.info(msg)
                         yield record
                     else:
+                        not_in_range = True
                         LOGGER.info('The record is not in the datetime range')
                 else:
                     LOGGER.error('Invalid record detected')
@@ -235,7 +247,12 @@ class VantagePro2(object):
                     break
                 r_index += 1
             if finish:
-                LOGGER.info('Canceling download')
+                LOGGER.info('Canceling download : Finish')
+                self.link.write(self.ESC)
+                break
+            elif not_in_range:
+                msg = 'Page is not in the datetime range'
+                LOGGER.info('Canceling download : %s' % msg)
                 self.link.write(self.ESC)
                 break
             else:
@@ -302,8 +319,8 @@ class VantagePro2(object):
 
     def _check_revision(self):
         '''Check firmware date and get data format revision.'''
-         #Rev "A" firmware, dated before April 24, 2002 uses the old format.
-         #Rev "B" firmware dated on or after April 24, 2002
+        #Rev "A" firmware, dated before April 24, 2002 uses the old format.
+        #Rev "B" firmware dated on or after April 24, 2002
         date = datetime(2002, 4, 24).date()
         self.RevA = self.RevB = True
         if self.firmware_date < date:
